@@ -1,7 +1,6 @@
 from keyring import get_password
 from mongoengine import *
-from enum import Enum
-
+from cryptomodel.operations import OPERATIONS
 
 
 
@@ -25,7 +24,7 @@ class user_notification(Document):
     fields_to_send = StringField()  ### collection:field latest date ?
     ### collection:field by latest user_id ?
     source_id = ObjectIdField()
-    operation = StringField(choices=OPERATIONS)
+    operation = StringField(choices=OPERATIONS.choices())
 
 
 class user_transaction(Document):
